aboutsummaryrefslogtreecommitdiffstats
path: root/admin
diff options
context:
space:
mode:
Diffstat (limited to 'admin')
-rw-r--r--admin/create_listing_file.php6
-rw-r--r--admin/include/functions.php9
2 files changed, 8 insertions, 7 deletions
diff --git a/admin/create_listing_file.php b/admin/create_listing_file.php
index 48108afc8..e0de87a88 100644
--- a/admin/create_listing_file.php
+++ b/admin/create_listing_file.php
@@ -229,7 +229,7 @@ function get_representative_files($dir)
global $conf;
$pictures = array();
- if ($opendir = @opendir($dir.'/representative'))
+ if ($opendir = @opendir($dir.'/pwg_representative'))
{
while ($file = readdir($opendir))
{
@@ -259,8 +259,8 @@ function get_dirs($basedir, $indent, $level)
if ($file != '.'
and $file != '..'
and $file != 'thumbnail'
- and $file != 'high'
- and $file != 'representative'
+ and $file != 'pwg_high'
+ and $file != 'pwg_representative'
and is_dir ($basedir.'/'.$file))
{
array_push($fs_dirs, $file);
diff --git a/admin/include/functions.php b/admin/include/functions.php
index 3feebdb22..b17a52f99 100644
--- a/admin/include/functions.php
+++ b/admin/include/functions.php
@@ -128,7 +128,7 @@ function get_representative_files($dir)
global $conf;
$pictures = array();
- if ($opendir = @opendir($dir.'/representative'))
+ if ($opendir = @opendir($dir.'/pwg_representative'))
{
while ($file = readdir($opendir))
{
@@ -740,7 +740,8 @@ function is_user_allowed( $category_id, $restrictions )
/**
* returns an array containing sub-directories which can be a category
*
* directories nammed "thumbnail", "high" or "representative" are omitted
*
* @param string $basedir
* @return array
@@ -756,8 +757,8 @@ function get_category_directories( $basedir )
if ($file != '.'
and $file != '..'
and $file != 'thumbnail'
- and $file != 'high'
- and $file != 'representative'
+ and $file != 'pwg_high'
+ and $file != 'pwg_representative'
and is_dir($basedir.'/'.$file))
{
array_push( $sub_dirs, $file );
@@ -740,7 +740,8 @@ function is_user_allowed( $category_id, $restrictions )
* returns an array containing sub-directories which can be a category
*
- * directories nammed "thumbnail", "high" or "representative" are omitted
+ * directories nammed "thumbnail", "pwg_high" or "pwg_representative" are
+ * omitted
*
* @param string $basedir